
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.037
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Perl client library for the OPNsense REST API",
  "dist_author" => [
    "Dean Hamstead <dean\@fragfest.com.au>"
  ],
  "dist_name" => "WebService-OPNsense",
  "dist_version" => "0.003",
  "license" => "mit",
  "module_name" => "WebService::OPNsense",
  "recursive_test_files" => 1,
  "requires" => {
    "Carp" => 0,
    "Const::Fast" => 0,
    "Exporter::Shiny" => 0,
    "Exporter::Tiny" => 0,
    "JSON::MaybeXS" => 0,
    "Moo" => 0,
    "Ref::Util" => 0,
    "URI::Escape" => 0,
    "URI::Template" => 0,
    "UUID::Tiny" => 0,
    "WebService::Client" => 0,
    "namespace::clean" => 0,
    "perl" => "5.024",
    "strictures" => 2
  },
  "test_requires" => {
    "File::Spec" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Net::CIDR::Lite" => 0,
    "Net::Netmask" => 0,
    "NetAddr::IP" => 0,
    "Test2::V1" => "1.302217",
    "Test::LWP::UserAgent" => 0,
    "Test::More" => 0,
    "constant" => 0
  }
);


my %fallback_build_requires = (
  "File::Spec" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.28",
  "Net::CIDR::Lite" => 0,
  "Net::Netmask" => 0,
  "NetAddr::IP" => 0,
  "Test2::V1" => "1.302217",
  "Test::LWP::UserAgent" => 0,
  "Test::More" => 0,
  "constant" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
