
BEGIN {
    unless ( $ENV{AUTHOR_TESTING} ) {
        print qq{1..0 # SKIP these tests are for testing by the author\n};
        exit;
    }
}

use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::NoTabs 0.15

use Test::More 0.88;
use Test::NoTabs;

my @files = (
    'Build.PL',
    'Changes',
    'LICENSE',
    'META.json',
    'META.yml',
    'Makefile.PL',
    'README',
    'cpanfile',
    'examples/reverse_dns.pl',
    'examples/service_info.pl',
    'lib/WebService/OPNsense.pm',
    'lib/WebService/OPNsense/Backup.pm',
    'lib/WebService/OPNsense/CaptivePortal/Access.pm',
    'lib/WebService/OPNsense/CaptivePortal/Service.pm',
    'lib/WebService/OPNsense/CaptivePortal/Session.pm',
    'lib/WebService/OPNsense/CaptivePortal/Settings.pm',
    'lib/WebService/OPNsense/CaptivePortal/Voucher.pm',
    'lib/WebService/OPNsense/Constants.pm',
    'lib/WebService/OPNsense/Cron/Service.pm',
    'lib/WebService/OPNsense/Cron/Settings.pm',
    'lib/WebService/OPNsense/Diagnostics.pm',
    'lib/WebService/OPNsense/Dnsmasq/Leases.pm',
    'lib/WebService/OPNsense/Dnsmasq/Service.pm',
    'lib/WebService/OPNsense/Dnsmasq/Settings.pm',
    'lib/WebService/OPNsense/Exception.pm',
    'lib/WebService/OPNsense/Firewall.pm',
    'lib/WebService/OPNsense/Firewall/Alias.pm',
    'lib/WebService/OPNsense/Firewall/Category.pm',
    'lib/WebService/OPNsense/Firewall/DNat.pm',
    'lib/WebService/OPNsense/Firewall/Filter.pm',
    'lib/WebService/OPNsense/Firewall/Npt.pm',
    'lib/WebService/OPNsense/Firewall/OneToOne.pm',
    'lib/WebService/OPNsense/Firewall/Role/NAT.pm',
    'lib/WebService/OPNsense/Firewall/SourceNat.pm',
    'lib/WebService/OPNsense/HASync.pm',
    'lib/WebService/OPNsense/IDS/Service.pm',
    'lib/WebService/OPNsense/IDS/Settings.pm',
    'lib/WebService/OPNsense/IPsec/Connections.pm',
    'lib/WebService/OPNsense/IPsec/KeyPairs.pm',
    'lib/WebService/OPNsense/IPsec/Leases.pm',
    'lib/WebService/OPNsense/IPsec/ManualSpd.pm',
    'lib/WebService/OPNsense/IPsec/Pools.pm',
    'lib/WebService/OPNsense/IPsec/PreSharedKeys.pm',
    'lib/WebService/OPNsense/IPsec/Sad.pm',
    'lib/WebService/OPNsense/IPsec/Service.pm',
    'lib/WebService/OPNsense/IPsec/Sessions.pm',
    'lib/WebService/OPNsense/IPsec/Settings.pm',
    'lib/WebService/OPNsense/IPsec/Spd.pm',
    'lib/WebService/OPNsense/IPsec/Tunnel.pm',
    'lib/WebService/OPNsense/IPsec/Vti.pm',
    'lib/WebService/OPNsense/Interfaces.pm',
    'lib/WebService/OPNsense/Kea/CtrlAgent.pm',
    'lib/WebService/OPNsense/Kea/Ddns.pm',
    'lib/WebService/OPNsense/Kea/Dhcpv4.pm',
    'lib/WebService/OPNsense/Kea/Dhcpv6.pm',
    'lib/WebService/OPNsense/Kea/Leases.pm',
    'lib/WebService/OPNsense/Kea/Service.pm',
    'lib/WebService/OPNsense/Normalize.pm',
    'lib/WebService/OPNsense/Object.pm',
    'lib/WebService/OPNsense/OpenVPN/ClientOverwrites.pm',
    'lib/WebService/OPNsense/OpenVPN/Export.pm',
    'lib/WebService/OPNsense/OpenVPN/Instances.pm',
    'lib/WebService/OPNsense/OpenVPN/Service.pm',
    'lib/WebService/OPNsense/Role/APIPath.pm',
    'lib/WebService/OPNsense/Role/Crud.pm',
    'lib/WebService/OPNsense/Role/ItemCrud.pm',
    'lib/WebService/OPNsense/Role/KeaItemCrud.pm',
    'lib/WebService/OPNsense/Role/Service.pm',
    'lib/WebService/OPNsense/Role/Settings.pm',
    'lib/WebService/OPNsense/Routes.pm',
    'lib/WebService/OPNsense/System.pm',
    'lib/WebService/OPNsense/TrafficShaper/Service.pm',
    'lib/WebService/OPNsense/TrafficShaper/Settings.pm',
    'lib/WebService/OPNsense/Unbound/Diagnostics.pm',
    'lib/WebService/OPNsense/Unbound/Overview.pm',
    'lib/WebService/OPNsense/Unbound/Service.pm',
    'lib/WebService/OPNsense/Unbound/Settings.pm',
    't/.perlcriticrc',
    't/00-compile.t',
    't/000_basic.t',
    't/010_constants.t',
    't/011_constants_consistency.t',
    't/020_exception.t',
    't/030_normalize.t',
    't/040_object.t',
    't/050_build.t',
    't/051_http_mock.t',
    't/052_uri_encoding.t',
    't/060_backup.t',
    't/author-clean-namespaces.t',
    't/author-critic.t',
    't/author-distmeta.t',
    't/author-eof.t',
    't/author-eol.t',
    't/author-no-breakpoints.t',
    't/author-no-tabs.t',
    't/author-pod-coverage.t',
    't/author-pod-syntax.t',
    't/author-portability.t',
    't/release-kwalitee.t',
    't/release-pause-permissions.t',
    't/release-test-legal.t',
    't/release-unused-vars.t'
);

notabs_ok($_) foreach @files;
done_testing;
