#!perl

BEGIN {
    unless ( $ENV{AUTHOR_TESTING} ) {
        print qq{1..0 # SKIP these tests are for testing by the author\n};
        exit;
    }
}

# This file was automatically generated by Dist::Zilla::Plugin::MetaTests
use strict;
use warnings;
use Test::CPAN::Meta;

meta_yaml_ok();
